@@ -2,7 +2,6 @@
 # Copyright (c) Max-Planck-Institut für Eisenforschung GmbH - Computational Materials Design (CM) Department
 # Distributed under the terms of "New BSD License", see the LICENSE file.
 
-from __future__ import print_function
 
 import h5py
 import os
@@ -446,17 +445,24 @@ class FileHDFio(object):
             df = pandas.DataFrame(val)
             return df
 
-    def get(self, key):
+    def get(self, key, default = None):
         """
         Internal wrapper function for __getitem__() - self[name]
 
         Args:
             key (str, slice): path to the data or key of the data object
+            default (object): default value to return if key doesn't exist
 
         Returns:
             dict, list, float, int: data or data object
         """
-        return self.__getitem__(key)
+        try:
+            return self.__getitem__(key)
+        except ValueError:
+            if default is not None:
+                return default
+            else:
+                raise
 
     def put(self, key, value):
         """
