@@ -2,7 +2,6 @@
 # Copyright (c) Max-Planck-Institut für Eisenforschung GmbH - Computational Materials Design (CM) Department
 # Distributed under the terms of "New BSD License", see the LICENSE file.
 
-from __future__ import print_function
 
 # import copy
 import signal
@@ -675,7 +674,7 @@ class GenericJob(JobCore):
                 self._logger.info("run repair " + str(self.job_id))
                 status = "initialized"
                 master_id, parent_id = self.master_id, self.parent_id
-                self.remove()
+                self.remove(_protect_childs=False)
                 self.reset_job_id()
                 self.master_id, self.parent_id = master_id, parent_id
             if repair and self.job_id and not self.status.finished:
@@ -1145,7 +1144,7 @@ class GenericJob(JobCore):
         if hdf is not None:
             self._hdf5 = hdf
         if group_name is not None:
-            self._hdf5.open(group_name)
+            self._hdf5 = self._hdf5.open(group_name)
         self._executable_activate_mpi()
         self._type_to_hdf()
         self._hdf5["status"] = self.status.string
