@@ -2,7 +2,6 @@
 # Copyright (c) Max-Planck-Institut für Eisenforschung GmbH - Computational Materials Design (CM) Department
 # Distributed under the terms of "New BSD License", see the LICENSE file.
 
-from __future__ import division, print_function
 from collections import OrderedDict
 from datetime import datetime
 import numpy as np
@@ -679,7 +678,7 @@ class ParallelMaster(GenericMaster):
                 "{} child project {}".format(self.job_name, self.project.__str__())
             )
             job = next(self._job_generator, None)
-            if (self.server.run_mode.non_modal or self.server.run_mode.queue) \
+            if (self.server.run_mode.non_modal or self.server.run_mode.queue or self.server.run_mode.modal) \
                     and job.server.run_mode.interactive:
                 self.run_if_interactive()
             elif self.server.run_mode.queue:
